@@ -12,13 +12,15 @@ abstract type UnionSemiMetric <: SemiMetric end
 
 abstract type UnionMetric <: Metric end
 
+abstract type UnionMinkowskiMetric <: MinkowskiMetric end
+
 ###########################################################
 #
 #   Metric types
 #
 ###########################################################
 
-struct Euclidean <: UnionMetric
+struct Euclidean <: UnionMinkowskiMetric
     thresh::Float64
 end
 
@@ -52,7 +54,7 @@ julia> pairwise(Euclidean(1e-12), x, x)
 """
 Euclidean() = Euclidean(0)
 
-struct WeightedEuclidean{W} <: UnionMetric
+struct WeightedEuclidean{W} <: UnionMinkowskiMetric
     weights::W
 end
 
@@ -94,10 +96,10 @@ struct WeightedSqEuclidean{W} <: UnionSemiMetric
     weights::W
 end
 
-struct Chebyshev <: UnionMetric end
+struct Chebyshev <: UnionMinkowskiMetric end
 
-struct Cityblock <: UnionMetric end
-struct WeightedCityblock{W} <: UnionMetric
+struct Cityblock <: UnionMinkowskiMetric end
+struct WeightedCityblock{W} <: UnionMinkowskiMetric
     weights::W
 end
 
@@ -105,10 +107,10 @@ struct TotalVariation <: UnionMetric end
 struct Jaccard <: UnionMetric end
 struct RogersTanimoto <: UnionMetric end
 
-struct Minkowski{T <: Real} <: UnionMetric
+struct Minkowski{T <: Real} <: UnionMinkowskiMetric
     p::T
 end
-struct WeightedMinkowski{W,T <: Real} <: UnionMetric
+struct WeightedMinkowski{W,T <: Real} <: UnionMinkowskiMetric
     weights::W
     p::T
 end
@@ -197,7 +199,7 @@ struct NormRMSDeviation <: PreMetric end
 # Union types
 const metrics = (Euclidean,SqEuclidean,PeriodicEuclidean,Chebyshev,Cityblock,TotalVariation,Minkowski,Hamming,Jaccard,RogersTanimoto,CosineDist,ChiSqDist,KLDivergence,RenyiDivergence,BrayCurtis,JSDivergence,SpanNormDist,GenKLDivergence)
 const weightedmetrics = (WeightedEuclidean,WeightedSqEuclidean,WeightedCityblock,WeightedMinkowski,WeightedHamming)
-const UnionMetrics = Union{UnionPreMetric,UnionSemiMetric,UnionMetric}
+const UnionMetrics = Union{UnionPreMetric,UnionSemiMetric,UnionMetric,UnionMinkowskiMetric}
 
 ###########################################################
 #
@@ -208,6 +210,7 @@ const UnionMetrics = Union{UnionPreMetric,UnionSemiMetric,UnionMetric}
 parameters(::UnionPreMetric) = nothing
 parameters(::UnionSemiMetric) = nothing
 parameters(::UnionMetric) = nothing
+parameters(::UnionMinkowskiMetric) = nothing
 parameters(d::PeriodicEuclidean) = d.periods
 for dist in weightedmetrics
     @eval parameters(d::$dist) = d.weights
